pub enum GetGroupConfigurationError {
BadRequest(String),
Forbidden(String),
InternalServerError(String),
MethodNotAllowed(String),
NotFound(String),
TooManyRequests(String),
}Expand description
Errors returned by GetGroupConfiguration
Variants
BadRequest(String)
The request includes one or more parameters that violate validation rules.
Forbidden(String)
The caller isn't authorized to make the request. Check permissions.
InternalServerError(String)
An internal error occurred while processing the request. Try again later.
MethodNotAllowed(String)
The request uses an HTTP method that isn't allowed for the specified resource.
NotFound(String)
One or more of the specified resources don't exist.
TooManyRequests(String)
You've exceeded throttling limits by making too many requests in a period of time.
Implementations
Sourceimpl GetGroupConfigurationError
impl GetGroupConfigurationError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<GetGroupConfigurationError>