pub struct ListGroupsOutput {
pub group_identifiers: Option<Vec<GroupIdentifier>>,
pub next_token: Option<String>,
}Fields
group_identifiers: Option<Vec<GroupIdentifier>>A list of GroupIdentifier objects. Each identifier is an object that contains both the Name and the GroupArn.
next_token: Option<String>If present, indicates that more output is available than is included in the current response. Use this value in the NextToken request parameter in a subsequent call to the operation to get the next part of the output. You should repeat this until the NextToken response element comes back as null.